# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lakeside.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='lakeside.proto',
  package='lakeside',
  syntax='proto2',
  serialized_pb=_b('\n\x0elakeside.proto\x12\x08lakeside\"\x14\n\x04Ping\x12\x0c\n\x04type\x18\x01 \x02(\x05\"5\n\nBulbValues\x12\x12\n\nbrightness\x18\x01 \x02(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x05\"\x9c\x01\n\tBulbState\x12\x0f\n\x07\x63ommand\x18\x01 \x02(\x05\x12$\n\x06values\x18\x02 \x01(\x0b\x32\x14.lakeside.BulbValues\x12\r\n\x05power\x18\x03 \x01(\x05\x12\x10\n\x08unknown1\x18\x04 \x01(\x05\x12%\n\x07values2\x18\x05 \x01(\x0b\x32\x14.lakeside.BulbValues\x12\x10\n\x08unknown2\x18\x06 \x01(\x05\"l\n\nBulbPacket\x12\x10\n\x08unknown1\x18\x01 \x02(\x05\x12&\n\tbulbstate\x18\x02 \x01(\x0b\x32\x13.lakeside.BulbState\x12$\n\x07\x62ulbset\x18\x03 \x01(\x0b\x32\x13.lakeside.BulbState\">\n\x08\x42ulbInfo\x12\x0c\n\x04type\x18\x01 \x02(\x05\x12$\n\x06packet\x18\x02 \x01(\x0b\x32\x14.lakeside.BulbPacket\"p\n\nEufyPacket\x12\x10\n\x08sequence\x18\x01 \x02(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x02(\t\x12\x1c\n\x04ping\x18\x03 \x01(\x0b\x32\x0e.lakeside.Ping\x12$\n\x08\x62ulbinfo\x18\x05 \x01(\x0b\x32\x12.lakeside.BulbInfo')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='lakeside.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='lakeside.Ping.type', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=48,
)


_BULBVALUES = _descriptor.Descriptor(
  name='BulbValues',
  full_name='lakeside.BulbValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='brightness', full_name='lakeside.BulbValues.brightness', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='lakeside.BulbValues.temperature', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=103,
)


_BULBSTATE = _descriptor.Descriptor(
  name='BulbState',
  full_name='lakeside.BulbState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='lakeside.BulbState.command', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='lakeside.BulbState.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='power', full_name='lakeside.BulbState.power', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown1', full_name='lakeside.BulbState.unknown1', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values2', full_name='lakeside.BulbState.values2', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unknown2', full_name='lakeside.BulbState.unknown2', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=262,
)


_BULBPACKET = _descriptor.Descriptor(
  name='BulbPacket',
  full_name='lakeside.BulbPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unknown1', full_name='lakeside.BulbPacket.unknown1', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bulbstate', full_name='lakeside.BulbPacket.bulbstate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bulbset', full_name='lakeside.BulbPacket.bulbset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=372,
)


_BULBINFO = _descriptor.Descriptor(
  name='BulbInfo',
  full_name='lakeside.BulbInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='lakeside.BulbInfo.type', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packet', full_name='lakeside.BulbInfo.packet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=436,
)


_EUFYPACKET = _descriptor.Descriptor(
  name='EufyPacket',
  full_name='lakeside.EufyPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='lakeside.EufyPacket.sequence', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='lakeside.EufyPacket.code', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping', full_name='lakeside.EufyPacket.ping', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bulbinfo', full_name='lakeside.EufyPacket.bulbinfo', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=550,
)

_BULBSTATE.fields_by_name['values'].message_type = _BULBVALUES
_BULBSTATE.fields_by_name['values2'].message_type = _BULBVALUES
_BULBPACKET.fields_by_name['bulbstate'].message_type = _BULBSTATE
_BULBPACKET.fields_by_name['bulbset'].message_type = _BULBSTATE
_BULBINFO.fields_by_name['packet'].message_type = _BULBPACKET
_EUFYPACKET.fields_by_name['ping'].message_type = _PING
_EUFYPACKET.fields_by_name['bulbinfo'].message_type = _BULBINFO
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['BulbValues'] = _BULBVALUES
DESCRIPTOR.message_types_by_name['BulbState'] = _BULBSTATE
DESCRIPTOR.message_types_by_name['BulbPacket'] = _BULBPACKET
DESCRIPTOR.message_types_by_name['BulbInfo'] = _BULBINFO
DESCRIPTOR.message_types_by_name['EufyPacket'] = _EUFYPACKET

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), dict(
  DESCRIPTOR = _PING,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.Ping)
  ))
_sym_db.RegisterMessage(Ping)

BulbValues = _reflection.GeneratedProtocolMessageType('BulbValues', (_message.Message,), dict(
  DESCRIPTOR = _BULBVALUES,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.BulbValues)
  ))
_sym_db.RegisterMessage(BulbValues)

BulbState = _reflection.GeneratedProtocolMessageType('BulbState', (_message.Message,), dict(
  DESCRIPTOR = _BULBSTATE,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.BulbState)
  ))
_sym_db.RegisterMessage(BulbState)

BulbPacket = _reflection.GeneratedProtocolMessageType('BulbPacket', (_message.Message,), dict(
  DESCRIPTOR = _BULBPACKET,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.BulbPacket)
  ))
_sym_db.RegisterMessage(BulbPacket)

BulbInfo = _reflection.GeneratedProtocolMessageType('BulbInfo', (_message.Message,), dict(
  DESCRIPTOR = _BULBINFO,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.BulbInfo)
  ))
_sym_db.RegisterMessage(BulbInfo)

EufyPacket = _reflection.GeneratedProtocolMessageType('EufyPacket', (_message.Message,), dict(
  DESCRIPTOR = _EUFYPACKET,
  __module__ = 'lakeside_pb2'
  # @@protoc_insertion_point(class_scope:lakeside.EufyPacket)
  ))
_sym_db.RegisterMessage(EufyPacket)


# @@protoc_insertion_point(module_scope)
